# PolymorphicOctoPrintEvent


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [readonly] 
**subject_pattern** | [**OctoPrintServerStatusSubjectPatternEnum**](OctoPrintServerStatusSubjectPatternEnum.md) |  | 
**payload** | **dict(str, object)** |  | 
**created_dt** | **datetime** |  | [readonly] 
**event_type** | [**OctoPrintServerStatusType**](OctoPrintServerStatusType.md) |  | 
**octoprint_server** | **int** |  | 
**pi** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


